/********************************** (C) COPYRIGHT *******************************
* File Name          : Usb.H
* Author             : EListen
* Version            : V1.00
* Date               : 2022-07-31
* Description        : 
*******************************************************************************/
#ifndef USB_H
#define USB_H

#define Fullspeed          1
#define WINUSB             1
#define THIS_ENDP0_SIZE    64
#define DAP_PACKET_COUNT   4

#define USB_DESCR_TYP_IAD      0x0B
#define USB_DESCR_TYP_BOS      0x0F
#define SET_LINE_CODING        0x20        // Configures DTE rate, stop-bits, parity, and number-of-character
#define GET_LINE_CODING        0x21        // This request allows the host to find out the currently configured line coding.
#define SET_CONTROL_LINE_STATE 0x22        // This request generates RS-232/V.24 style control signals.

#define UIS_TOKEN_SETUP_EP0  (UIS_TOKEN_SETUP | 0)

#define UIS_TOKEN_IN_EP0  (UIS_TOKEN_IN | 0)
#define UIS_TOKEN_IN_EP1  (UIS_TOKEN_IN | 1)
#define UIS_TOKEN_IN_EP2  (UIS_TOKEN_IN | 2)
#define UIS_TOKEN_IN_EP3  (UIS_TOKEN_IN | 3)
#define UIS_TOKEN_IN_EP4  (UIS_TOKEN_IN | 4)

#define UIS_TOKEN_OUT_EP0  (UIS_TOKEN_OUT | 0)
#define UIS_TOKEN_OUT_EP1  (UIS_TOKEN_OUT | 1)
#define UIS_TOKEN_OUT_EP2  (UIS_TOKEN_OUT | 2)
#define UIS_TOKEN_OUT_EP3  (UIS_TOKEN_OUT | 3)
#define UIS_TOKEN_OUT_EP4  (UIS_TOKEN_OUT | 4)

#if (WINUSB == 1)
UINT8C DevDesc[] =
{
    0x12,                            /* bLength */
    USB_DESCR_TYP_DEVICE,            /* bDescriptorType */
    0x10, 0x02,                      /* bcdUSB */
    0xEF,                            /* bDeviceClass : Base Class EFh (Miscellaneous) */
    0x02,                            /* bDeviceSubClass */
    0x01,                            /* bDeviceProtocol : Interface Association Descriptor */
    THIS_ENDP0_SIZE,                 /* bMaxPackeSize0 */
    0x28, 0x0D,                      /* idVender */
    0x04, 0x02,                      /* idProduct */
    0x00, 0x01,                      /* bcdDevice */
    0x01,                            /* iManufacturer */
    0x02,                            /* iProduct */
    0x03,                            /* iSerialNumber */
    0x01                             /* bNumConfigurations */
};
UINT8C CfgDesc[] =
{
    //
    0x09,                            /* bLength */ 
    USB_DESCR_TYP_CONFIG,            /* bDescriptorType */
    0x62, 0x00,                      /* wTotalLength */
    0x03,                            /* bNumInterfaces */ 
    0x01,                            /* bConfigurationValue */ 
    0x00,                            /* iConfiguration */ 
    0x80,                            /* bmAttributes */ 
    0xfa,                            /* bMaxPower */ 
    //ӿ : DAP
    0x09,                            /* bLength */
    USB_DESCR_TYP_INTERF,            /* bDescriptorType */
    0x00,                            /* bInterfaceNumber */
    0x00,                            /* bAlternateSetting */
    0x02,                            /* bNumEndpoints */
    0xff,                            /* bInterfaceClass */
    0x00,                            /* bInterfaceSubClass */  
    0x00,                            /* bInterfaceProtocol */
    0x04,                            /* iInterface */
    //˵
    0x07,                            /* bLength */
    USB_DESCR_TYP_ENDP,              /* bDescriptorType */
    0x01,                            /* bEndpointAddress */
    0x02,                            /* bmAttributes */
    0x40,0x00,                       /* wMaxPackeSize */
    0x00,                            /* bInterval */
    //˵
    0x07,                            /* bLength */
    USB_DESCR_TYP_ENDP,              /* bDescriptorType */
    0x81,                            /* bEndpointAddress */
    0x02,                            /* bmAttributes */
    0x40,0x00,                       /* wMaxPackeSize */
    0x00,                            /* bInterval */
    //ӿڹ : CDC
    0x08,                            /* bLength */
    USB_DESCR_TYP_IAD,               /* bDescriptorType */
    0x01,                            /* bFirstInterface */
    0x02,                            /* bInterfaceCount */
    0x02,                            /* bFunctionClass */
    0x02,                            /* bFunctionSubClass */
    0x01,                            /* bFunctionProtocol */  
    0x05,                            /* iFunction : ַ */
    //ӿ : CDC_Data
    0x09,                            /* bLength */
    USB_DESCR_TYP_INTERF,            /* bDescriptorType */
    0x01,                            /* bInterfaceNumber */
    0x00,                            /* bAlternateSetting */
    0x02,                            /* bNumEndpoints */
    0x0A,                            /* bInterfaceClass */
    0x00,                            /* bInterfaceSubClass */  
    0x00,                            /* bInterfaceProtocol */
    0x00,                            /* iInterface */
    //˵
    0x07,                            /* bLength */
    USB_DESCR_TYP_ENDP,              /* bDescriptorType */
    0x02,                            /* bEndpointAddress */
    0x02,                            /* bmAttributes */
    0x40,0x00,                       /* wMaxPackeSize */
    0x01,                            /* bInterval */
    //˵
    0x07,                            /* bLength */
    USB_DESCR_TYP_ENDP,              /* bDescriptorType */
    0x82,                            /* bEndpointAddress */
    0x02,                            /* bmAttributes */
    0x40,0x00,                       /* wMaxPackeSize */
    0x01,                            /* bInterval */
    //ӿ : Communications and CDC Control
    0x09,                            /* bLength */
    USB_DESCR_TYP_INTERF,            /* bDescriptorType */
    0x02,                            /* bInterfaceNumber */
    0x00,                            /* bAlternateSetting */
    0x01,                            /* bNumEndpoints */
    0x02,                            /* bInterfaceClass */
    0x02,                            /* bInterfaceSubClass */  
    0x01,                            /* bInterfaceProtocol */
    0x00,                            /* iInterface */
    //ضӿ
    0x05,                            /* bFunctionLength */ 
    0x24,                            /* bDescriptorType : CS_INTERFACE*/ 
    0x00,                            /* bDescriptorSubtype : Header Functional Descriptor */ 
    0x10,0x01,                       /* bcdCDC : CDC Spec Version*/
    //ضӿ
    0x05,                            /* bFunctionLength */ 
    0x24,                            /* bDescriptorType : CS_INTERFACE*/ 
    0x01,                            /* bDescriptorSubtype : Call Management functional descriptor */ 
    0x00,                            /* bmCapabilities */
    0x01,                            /* bDataInterface*/
    //ضӿ
    0x04,                            /* bFunctionLength */ 
    0x24,                            /* bDescriptorType : CS_INTERFACE*/ 
    0x02,                            /* bDescriptorSubtype : Abstract Control Management Functional Descriptor */ 
    0x02,                            /* bmCapabilities : Support Set_Line_Coding */
    //ضӿ
    0x05,                            /* bFunctionLength */ 
    0x24,                            /* bDescriptorType : CS_INTERFACE*/ 
    0x06,                            /* bDescriptorSubtype : Union Functional Descriptor */ 
    0x00,                            /* bControlInterface */
    0x01,                            /* bSubordinateInterface0*/
    //˵
    0x07,                            /* bLength */
    USB_DESCR_TYP_ENDP,              /* bDescriptorType */
    0x84,                            /* bEndpointAddress */
    0x03,                            /* bmAttributes */
    0x08,0x00,                       /* wMaxPackeSize */
    0xFF,                            /* bInterval */
};
#else
#Err no USB interface define
#endif

//CDC Set_Line_Coding
UINT8I LineCoding[] = 
{
    0x00, 0xe1, 0x00, 0x00,          /* dwDTERate : ʼΪ57600 */
    0x00,                            /* bCharFormat : 1ֹͣλ */
    0x00,                            /* bParityType : У */
    0x08                             /* bDataBits : 8λ */
}; 

/*ַ */
// 
UINT8C LangDescr[] = 
{
    0x04,                            /* bLength */
    USB_DESCR_TYP_STRING,            /* bDescriptorType */
    0x09,                            /* wLANGID[0] */
    0x04                             /* wLANGID[1] */
};
// Ϣ:ARM
UINT8C ManuInfo[] = 
{
    0x08,                            /* bLength */
    USB_DESCR_TYP_STRING,            /* bDescriptorType */
    'A', 0x00,                       /* wcChar0 */
    'R', 0x00,                       /* wcChar1 */
    'M', 0x00,                       /* wcChar2 */
};
// ƷϢ: DAP-Link-II
UINT8C ProdInfo[] =
{
  0x26,                              /* bLength */
  USB_DESCR_TYP_STRING,              /* bDescriptorType */
  'E', 0x00,                         /* wcChar0 */
  'L', 0x00,                         /* wcChar1 */
  'i', 0x00,                         /* wcChar2 */
  's', 0x00,                         /* wcChar3 */
  't', 0x00,                         /* wcChar4 */
  'e', 0x00,                         /* wcChar5 */
  'n', 0x00,                         /* wcChar6 */
  ' ', 0x00,                         /* wcChar7 */
  'D', 0x00,                         /* wcChar8 */
  'A', 0x00,                         /* wcChar9 */
  'P', 0x00,                         /* wcChar10 */
  'L', 0x00,                         /* wcChar11 */
  'i', 0x00,                         /* wcChar12 */
  'n', 0x00,                         /* wcChar13 */
  'k', 0x00,                         /* wcChar14 */
  ' ', 0x00,                         /* wcChar15 */
  'V', 0x00,                         /* wcChar16 */
  '2', 0x00,                         /* wcChar17 */
};
// к: 3V3-IO-12345
UINT8C SerNumber[] =
{
  0x1a,                              /* bLength */
  USB_DESCR_TYP_STRING,              /* bDescriptorType */
  'T', 0x00,                         /* wcChar0 */
  'U', 0x00,                         /* wcChar1 */
  'S', 0x00,                         /* wcChar2 */
  'B', 0x00,                         /* wcChar3 */
  '1', 0x00,                         /* wcChar4 */
  '2', 0x00,                         /* wcChar5 */
  '3', 0x00,                         /* wcChar6 */
  '4', 0x00,                         /* wcChar7 */
  '5', 0x00,                         /* wcChar8 */
  '6', 0x00,                         /* wcChar9 */
  'F', 0x00,                         /* wcChar10 */
  'S', 0x00,                         /* wcChar11 */
};
// ӿ: CMSIS-DAP
UINT8C DAPInfo[] =
{
  0x1a,                              /* bLength */
  USB_DESCR_TYP_STRING,              /* bDescriptorType */
  'C', 0x00,                         /* wcChar0 */
  'M', 0x00,                         /* wcChar1 */
  'S', 0x00,                         /* wcChar2 */
  'I', 0x00,                         /* wcChar3 */
  'S', 0x00,                         /* wcChar4 */
  '-', 0x00,                         /* wcChar5 */
  'D', 0x00,                         /* wcChar6 */
  'A', 0x00,                         /* wcChar7 */
  'P', 0x00,                         /* wcChar8 */
  ' ', 0x00,                         /* wcChar9 */
  'v', 0x00,                         /* wcChar10 */
  '2', 0x00,                         /* wcChar11 */
};
//CDC
UINT8C CDCInfo[] =
{
    0x18,                                             /* bLength */
    USB_DESCR_TYP_STRING,                             /* bDescriptorType */
    'D', 0x00,                                        /* wcChar0 */
    'a', 0x00,                                        /* wcChar1 */
    'p', 0x00,                                        /* wcChar2 */
    'l', 0x00,                                        /* wcChar3 */
    'i', 0x00,                                        /* wcChar4 */
    'n', 0x00,                                        /* wcChar5 */
    'k', 0x00,                                        /* wcChar6 */
    '-', 0x00,                                        /* wcChar7 */
    'C', 0x00,                                        /* wcChar8 */
    'D', 0x00,                                        /* wcChar9 */
    'C', 0x00,                                        /* wcChar10 */
};

UINT8C BOSDesc[] =
{
    0x05,                                      /* bLength */
    USB_DESCR_TYP_BOS,                         /* bDescriptorType */
    0x28, 0x00,                                /* wTotalLength */
    0x02,                                      /* bNumDeviceCaps */
    0x07, 0x10, 0x02, 0x00, 0x00, 0x00, 0x00,
    0x1C,                                      /* bLength */
    0x10,                                      /* bDescriptorType */
    0x05,                                      /* bDevCapabilityType */
    0x00,                                      /* bReserved */
    0xDF, 0x60, 0xDD, 0xD8,                    /* PlatformCapabilityUUID */
    0x89, 0x45, 0xC7, 0x4C,
    0x9C, 0xD2, 0x65, 0x9D,
    0x9E, 0x64, 0x8A, 0x9F,
    0x00, 0x00, 0x03, 0x06,    /* >= Win 8.1 *//* dwWindowsVersion*/
    0xAA, 0x00,                                /* wDescriptorSetTotalLength */
    0x20,                                      /* bVendorCode */
    0x00                                       /* bAltEnumCode */
};

UINT8C WINDesc[] =
{
    ///////////////////////////////////////
    /// WCID20 descriptor set descriptor
    ///////////////////////////////////////
    0x0a, 0x00,                                       /* wLength */
    0x00, 0x00,                                       /* wDescriptorType */
    0x00, 0x00, 0x03, 0x06,                           /* dwWindowsVersion */
    0xaa, 0x00,                                       /* wDescriptorSetTotalLength */
    
    ///////////////////////////////////////
    /// WCID20 function subset descriptor
    ///////////////////////////////////////
    0x08, 0x00,                                       /* wLength */
    0x02, 0x00,                                       /* wDescriptorType */
    0x00,                                             /* bFirstInterface */
    0x00,                                             /* bReserved */
    0xa0, 0x00,                                       /* wSubsetLength */
    
    ///////////////////////////////////////
    /// WCID20 compatible ID descriptor
    ///////////////////////////////////////
    0x14, 0x00,                                       /* wLength */
    0x03, 0x00,                                       /* wDescriptorType */
    /* WINUSB */
    'W', 'I', 'N', 'U', 'S', 'B', 0x00, 0x00,         /* cCID_8 */
    /*  */
    0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   /* cSubCID_8 */
    
    ///////////////////////////////////////
    /// WCID20 registry property descriptor
    ///////////////////////////////////////
    0x84, 0x00,                                       /* wLength */
    0x04, 0x00,                                       /* wDescriptorType */
    0x07, 0x00,                                       /* wPropertyDataType */
    0x2a, 0x00,                                       /* wPropertyNameLength */
    /* DeviceInterfaceGUIDs */
    'D', 0x00, 'e', 0x00, 'v', 0x00, 'i', 0x00,       /* wcPropertyName_21 */
    'c', 0x00, 'e', 0x00, 'I', 0x00, 'n', 0x00,       /* wcPropertyName_21 */
    't', 0x00, 'e', 0x00, 'r', 0x00, 'f', 0x00,       /* wcPropertyName_21 */
    'a', 0x00, 'c', 0x00, 'e', 0x00, 'G', 0x00,       /* wcPropertyName_21 */
    'U', 0x00, 'I', 0x00, 'D', 0x00, 's', 0x00,       /* wcPropertyName_21 */
    0x00, 0x00,                                       /* wcPropertyName_21 */
    0x50, 0x00,                                       /* wPropertyDataLength */
    /* {CDB3B5AD-293B-4663-AA36-1AAE46463776} */
    '{', 0x00, 'C', 0x00, 'D', 0x00, 'B', 0x00,       /* wcPropertyData_40 */
    '3', 0x00, 'B', 0x00, '5', 0x00, 'A', 0x00,       /* wcPropertyData_40 */
    'D', 0x00, '-', 0x00, '2', 0x00, '9', 0x00,       /* wcPropertyData_40 */
    '3', 0x00, 'B', 0x00, '-', 0x00, '4', 0x00,       /* wcPropertyData_40 */
    '6', 0x00, '6', 0x00, '3', 0x00, '-', 0x00,       /* wcPropertyData_40 */
    'A', 0x00, 'A', 0x00, '3', 0x00, '6', 0x00,       /* wcPropertyData_40 */
    '-', 0x00, '1', 0x00, 'A', 0x00, 'A', 0x00,       /* wcPropertyData_40 */
    'E', 0x00, '4', 0x00, '6', 0x00, '4', 0x00,       /* wcPropertyData_40 */
    '6', 0x00, '3', 0x00, '7', 0x00, '7', 0x00,       /* wcPropertyData_40 */
    '6', 0x00, '}', 0x00, 0x00, 0x00, 0x00, 0x00,     /* wcPropertyData_40 */
};

#endif
/* END OF FILE */
